@@ -1,5 +1,5 @@
 package Locale::Maketext::Lexicon;
-$Locale::Maketext::Lexicon::VERSION = '0.64';
+$Locale::Maketext::Lexicon::VERSION = '0.65';
 
 use 5.004;
 use strict;
@@ -10,8 +10,8 @@ Locale::Maketext::Lexicon - Use other catalog formats in Maketext
 
 =head1 VERSION
 
-This document describes version 0.64 of Locale::Maketext::Lexicon,
-released May 28, 2007.
+This document describes version 0.65 of Locale::Maketext::Lexicon,
+released December 22, 2007.
 
 =head1 SYNOPSIS
 
@@ -150,6 +150,8 @@ utf8-strings.
 If C<_encoding> is set to C<locale>, the encoding from the
 current locale setting is used.
 
+=back
+
 =head2 Subclassing format handlers
 
 If you wish to override how sources specified in different data types
@@ -180,41 +182,47 @@ initialized previously.
 =cut
 
 our %Opts;
-sub option { shift if ref($_[0]); $Opts{lc $_[0]} }
-sub set_option { shift if ref($_[0]); $Opts{lc $_[0]} = $_[1] }
+sub option { shift if ref( $_[0] ); $Opts{ lc $_[0] } }
+sub set_option { shift if ref( $_[0] ); $Opts{ lc $_[0] } = $_[1] }
 
 sub encoding {
-    my $encoding = option(@_, 'encoding') or return;
+    my $encoding = option( @_, 'encoding' ) or return;
     return $encoding unless lc($encoding) eq 'locale';
 
-    no warnings 'uninitialized';
-    my ($country_language, $locale_encoding);
+    local $^W;    # no warnings 'uninitialized', really.
+    my ( $country_language, $locale_encoding );
 
     local $@;
     eval {
         require I18N::Langinfo;
-        $locale_encoding = I18N::Langinfo::langinfo(I18N::Langinfo::CODESET());
-    } or eval {
+        $locale_encoding =
+          I18N::Langinfo::langinfo( I18N::Langinfo::CODESET() );
+      }
+      or eval {
         require Win32::Console;
-        $locale_encoding = 'cp'.Win32::Console::OutputCP();
-    };
-    if (!$locale_encoding) {
+        $locale_encoding = 'cp' . Win32::Console::OutputCP();
+      };
+    if ( !$locale_encoding ) {
         foreach my $key (qw( LANGUAGE LC_ALL LC_MESSAGES LANG )) {
             $ENV{$key} =~ /^([^.]+)\.([^.:]+)/ or next;
-            ($country_language, $locale_encoding) = ($1, $2);
+            ( $country_language, $locale_encoding ) = ( $1, $2 );
             last;
         }
     }
-    if (defined $locale_encoding &&
-        lc($locale_encoding) eq 'euc' &&
-        defined $country_language) {
-        if ($country_language =~ /^ja_JP|japan(?:ese)?$/i) {
+    if (   defined $locale_encoding
+        && lc($locale_encoding) eq 'euc'
+        && defined $country_language )
+    {
+        if ( $country_language =~ /^ja_JP|japan(?:ese)?$/i ) {
             $locale_encoding = 'euc-jp';
-        } elsif ($country_language =~ /^ko_KR|korean?$/i) {
+        }
+        elsif ( $country_language =~ /^ko_KR|korean?$/i ) {
             $locale_encoding = 'euc-kr';
-        } elsif ($country_language =~ /^zh_CN|chin(?:a|ese)?$/i) {
+        }
+        elsif ( $country_language =~ /^zh_CN|chin(?:a|ese)?$/i ) {
             $locale_encoding = 'euc-cn';
-        } elsif ($country_language =~ /^zh_TW|taiwan(?:ese)?$/i) {
+        }
+        elsif ( $country_language =~ /^zh_TW|taiwan(?:ese)?$/i ) {
             $locale_encoding = 'euc-tw';
         }
     }
@@ -227,18 +235,19 @@ sub import {
     return unless @_;
 
     my %entries;
-    if (UNIVERSAL::isa($_[0], 'HASH')) {
+    if ( UNIVERSAL::isa( $_[0], 'HASH' ) ) {
+
         # a hashref with $lang as keys, [$format, $src ...] as values
-        %entries = %{$_[0]};
+        %entries = %{ $_[0] };
     }
-    elsif (@_ % 2 == 0) {
+    elsif ( @_ % 2 == 0 ) {
         %entries = ( '' => [ splice @_, 0, 2 ], @_ );
     }
 
     # expand the wildcard entry
-    if (my $wild_entry = delete $entries{'*'}) {
-        while (my ($format, $src) = splice(@$wild_entry, 0, 2)) {
-            next if ref($src); # XXX: implement globbing for the 'Tie' backend
+    if ( my $wild_entry = delete $entries{'*'} ) {
+        while ( my ( $format, $src ) = splice( @$wild_entry, 0, 2 ) ) {
+            next if ref($src);   # XXX: implement globbing for the 'Tie' backend
 
             my $pattern = quotemeta($src);
             $pattern =~ s/\\\*(?=[^*]+$)/\([-\\w]+\)/g or next;
@@ -251,70 +260,73 @@ sub import {
             ]eg;
 
             require File::Glob;
-            foreach my $file (File::Glob::bsd_glob($src)) {
+            foreach my $file ( File::Glob::bsd_glob($src) ) {
                 $file =~ /$pattern/ or next;
-                push @{$entries{$1}}, ($format => $file) if $1;
+                push @{ $entries{$1} }, ( $format => $file ) if $1;
             }
             delete $entries{$1}
-                unless !defined($1)
-                    or exists $entries{$1} and @{$entries{$1}};
+              unless !defined($1)
+                  or exists $entries{$1} and @{ $entries{$1} };
         }
     }
 
     %Opts = ();
-    foreach my $key (grep /^_/, keys %entries) {
-        set_option(lc(substr($key, 1)) => delete($entries{$key}));
+    foreach my $key ( grep /^_/, keys %entries ) {
+        set_option( lc( substr( $key, 1 ) ) => delete( $entries{$key} ) );
     }
-    my $OptsRef = { %Opts };
+    my $OptsRef = {%Opts};
 
-    while (my ($lang, $entry) = each %entries) {
+    while ( my ( $lang, $entry ) = each %entries ) {
         my $export = caller;
 
-        if (length $lang) {
+        if ( length $lang ) {
+
             # normalize language tag to Maketext's subclass convention
             $lang = lc($lang);
             $lang =~ s/-/_/g;
             $export .= "::$lang";
         }
 
-        my @pairs = @{$entry||[]} or die "no format specified";
+        my @pairs = @{ $entry || [] } or die "no format specified";
 
-        while (my ($format, $src) = splice(@pairs, 0, 2)) {
-            if (defined($src) and !ref($src) and $src =~ /\*/) {
-                unshift(@pairs, $format => $_) for File::Glob::bsd_glob($src);
+        while ( my ( $format, $src ) = splice( @pairs, 0, 2 ) ) {
+            if ( defined($src) and !ref($src) and $src =~ /\*/ ) {
+                unshift( @pairs, $format => $_ ) for File::Glob::bsd_glob($src);
                 next;
             }
 
             local $@;
-            my @content = eval {
-                $class->lexicon_get($src, scalar caller, $lang);
-            };
+            my @content =
+              eval { $class->lexicon_get( $src, scalar caller, $lang ); };
             next if $@ and $@ =~ /^next\b/;
             die $@ if $@;
 
             no strict 'refs';
             eval "use $class\::$format; 1" or die $@;
 
-            if (defined %{"$export\::Lexicon"}) {
-                if (ref(tied %{"$export\::Lexicon"}) eq __PACKAGE__) {
-                    tied(%{"$export\::Lexicon"})->_force;
+            if ( defined %{"$export\::Lexicon"} ) {
+                if ( ref( tied %{"$export\::Lexicon"} ) eq __PACKAGE__ ) {
+                    tied( %{"$export\::Lexicon"} )->_force;
                 }
+
                 # clear the memoized cache for old entries:
                 Locale::Maketext->clear_isa_scan;
+
                 # be very careful not to pollute the possibly tied lexicon
                 *{"$export\::Lexicon"} = {
                     %{"$export\::Lexicon"},
-                    %{"$class\::$format"->parse(@content)},
+                    %{ "$class\::$format"->parse(@content) },
                 };
             }
             else {
-                my $promise;
-                tie %{"$export\::Lexicon"}, __PACKAGE__, {
-                    Opts => $OptsRef,
-                    Export => "$export\::Lexicon",
-                    Class => "$class\::$format",
+                local $^W if $] >= 5.009;    # no warnings 'once', really.
+                tie %{"$export\::Lexicon"}, __PACKAGE__,
+                  {
+                    Opts    => $OptsRef,
+                    Export  => "$export\::Lexicon",
+                    Class   => "$class\::$format",
                     Content => \@content,
-                };
+                  };
             }
 
             length $lang or next;
@@ -323,10 +335,12 @@ sub import {
             my $caller = caller();
             next if $export->isa($caller);
 
-            push(@{"$export\::ISA"}, scalar caller);
+            push( @{"$export\::ISA"}, scalar caller );
 
-            if (my $style = option('style')) {
-                my $cref = $class->can(lc("_style_$style"))->( $class, $export->can('maketext') )
+            if ( my $style = option('style') ) {
+                my $cref =
+                  $class->can( lc("_style_$style") )
+                  ->( $class, $export->can('maketext') )
                   or die "Unknown style: $style";
 
                 # Avoid redefinition warnings
@@ -338,96 +352,106 @@ sub import {
 }
 
 sub _style_gettext {
-    my ($self, $orig) = @_;
+    my ( $self, $orig ) = @_;
 
     require Locale::Maketext::Lexicon::Gettext;
 
     sub {
         my $lh  = shift;
         my $str = shift;
-        return $orig->($lh, Locale::Maketext::Lexicon::Gettext::_gettext_to_maketext($str), @_);
-    }
+        return $orig->(
+            $lh, Locale::Maketext::Lexicon::Gettext::_gettext_to_maketext($str),
+            @_
+        );
+      }
 }
 
 sub TIEHASH {
-    my ($class, $args) = @_;
-    return bless($args, $class);
+    my ( $class, $args ) = @_;
+    return bless( $args, $class );
 
 }
 
 {
     no strict 'refs';
+
     sub _force {
         my $args = shift;
-        if (!$args->{Done}++) {
+        if ( !$args->{Done}++ ) {
             local *Opts = $args->{Opts};
-            *{$args->{Export}} = $args->{Class}->parse(@{$args->{Content}});
-            if (option('auto')) {
-                (\%{$args->{Export}})->{'_AUTO'} = 1;
+            *{ $args->{Export} } =
+              $args->{Class}->parse( @{ $args->{Content} } );
+            if ( option('auto') ) {
+                ( \%{ $args->{Export} } )->{'_AUTO'} = 1;
             }
         }
-        return \%{$args->{Export}};
+        return \%{ $args->{Export} };
     }
-    sub FETCH { _force($_[0])->{$_[1]} }
-    sub EXISTS { _force($_[0])->{$_[1]} }
-    sub DELETE { delete _force($_[0])->{$_[1]} }
-    sub SCALAR { scalar %{_force($_[0])} }
-    sub STORE { _force($_[0])->{$_[1]} = $_[2] }
-    sub CLEAR { %{_force($_[0])->{$_[1]}} = () }
-    sub NEXTKEY { each %{_force($_[0])} }
+    sub FETCH   { _force( $_[0] )->{ $_[1] } }
+    sub EXISTS  { _force( $_[0] )->{ $_[1] } }
+    sub DELETE  { delete _force( $_[0] )->{ $_[1] } }
+    sub SCALAR  { scalar %{ _force( $_[0] ) } }
+    sub STORE   { _force( $_[0] )->{ $_[1] } = $_[2] }
+    sub CLEAR   { %{ _force( $_[0] )->{ $_[1] } } = () }
+    sub NEXTKEY { each %{ _force( $_[0] ) } }
+
     sub FIRSTKEY {
-        my $hash = _force($_[0]);
-        my $a = scalar keys %$hash;
+        my $hash = _force( $_[0] );
+        my $a    = scalar keys %$hash;
         each %$hash;
     }
 }
 
 sub lexicon_get {
-    my ($class, $src, $caller, $lang) = @_;
+    my ( $class, $src, $caller, $lang ) = @_;
     return unless defined $src;
 
-    foreach my $type (qw(ARRAY HASH SCALAR GLOB), ref($src)) {
-        next unless UNIVERSAL::isa($src, $type);
+    foreach my $type ( qw(ARRAY HASH SCALAR GLOB), ref($src) ) {
+        next unless UNIVERSAL::isa( $src, $type );
 
         my $method = 'lexicon_get_' . lc($type);
         die "cannot handle source $type for $src: no $method defined"
-            unless $class->can($method);
+          unless $class->can($method);
 
-        return $class->$method($src, $caller, $lang);
+        return $class->$method( $src, $caller, $lang );
     }
 
     # default handler
-    return $class->lexicon_get_($src, $caller, $lang);
+    return $class->lexicon_get_( $src, $caller, $lang );
 }
 
 # for scalarrefs and arrayrefs we just dereference the $src
-sub lexicon_get_scalar { ${$_[1]} }
-sub lexicon_get_array  { @{$_[1]} }
+sub lexicon_get_scalar { ${ $_[1] } }
+sub lexicon_get_array  { @{ $_[1] } }
 
-sub lexicon_get_hash   {
-    my ($class, $src, $caller, $lang) = @_;
+sub lexicon_get_hash {
+    my ( $class, $src, $caller, $lang ) = @_;
     return map { $_ => $src->{$_} } sort keys %$src;
 }
 
-sub lexicon_get_glob   {
-    my ($class, $src, $caller, $lang) = @_;
+sub lexicon_get_glob {
+    my ( $class, $src, $caller, $lang ) = @_;
 
     no strict 'refs';
+    local $^W if $] >= 5.009;    # no warnings 'once', really.
 
     # be extra magical and check for DATA section
-    if (eof($src) and $src eq \*{"$caller\::DATA"} or $src eq \*{"main\::DATA"}) {
+    if ( eof($src) and $src eq \*{"$caller\::DATA"}
+        or $src eq \*{"main\::DATA"} )
+    {
+
         # okay, the *DATA isn't initiated yet. let's read.
         #
         require FileHandle;
         my $fh = FileHandle->new;
-        my $package = ( ($src eq \*{"main\::DATA"}) ? 'main' : $caller );
+        my $package = ( ( $src eq \*{"main\::DATA"} ) ? 'main' : $caller );
 
         if ( $package eq 'main' and -e $0 ) {
             $fh->open($0) or die "Can't open $0: $!";
         }
         else {
             my $level = 1;
-            while ( my ($pkg, $filename) = caller($level++) ) {
+            while ( my ( $pkg, $filename ) = caller( $level++ ) ) {
                 next unless $pkg eq $package;
                 next unless -e $filename;
                 next;
@@ -438,6 +462,7 @@ sub lexicon_get_glob   {
         }
 
         while (<$fh>) {
+
             # okay, this isn't foolproof, but good enough
             last if /^__DATA__$/;
         }
@@ -446,27 +471,30 @@ sub lexicon_get_glob   {
     }
 
     # fh containing the lines
-    my $pos = tell($src);
+    my $pos   = tell($src);
     my @lines = <$src>;
-    seek($src, $pos, 0);
+    seek( $src, $pos, 0 );
     return @lines;
 }
 
 # assume filename - search path, open and return its contents
 sub lexicon_get_ {
-    my ($class, $src, $caller, $lang) = @_;
+    my ( $class, $src, $caller, $lang ) = @_;
 
     require FileHandle;
     require File::Spec;
 
     my $fh = FileHandle->new;
-    my @path = split('::', $caller);
+    my @path = split( '::', $caller );
     push @path, $lang if length $lang;
 
-    $src = (grep { -e } map {
-        my @subpath = @path[0..$_];
-        map { File::Spec->catfile($_, @subpath, $src) } @INC;
-    } -1 .. $#path)[-1] unless -e $src;
+    $src = (
+        grep { -e } map {
+            my @subpath = @path[ 0 .. $_ ];
+            map { File::Spec->catfile( $_, @subpath, $src ) } @INC;
+          } -1 .. $#path
+      )[-1]
+      unless -e $src;
 
     defined $src or die 'next';
 
