@@ -38,31 +38,38 @@ calls to this lexicon will I<not> take any additional arguments.
 sub parse {
     my $set = 0;
     my $msg = undef;
-    my ($qr, $qq, $qc)  = (qr//, '', '');
+    my ($qr, $qq, $qc) = (qr//, '', '');
     my @out;
 
     # Set up the msgcat handler
-    { no strict 'refs';
-      *{Locale::Maketext::msgcat} = \&_msgcat; }
+    {
+        no strict 'refs';
+        *{Locale::Maketext::msgcat} = \&_msgcat;
+    }
 
     # Parse *.m files; Locale::Msgcat objects and *.cat are not yet supported.
     foreach (@_) {
-        s/[\015\012]*\z//; # fix CRLF issues
+        s/[\015\012]*\z//;    # fix CRLF issues
 
-        /^\$set (\d+)/                          ? do {  # set_id
+        /^\$set (\d+)/
+          ? do {              # set_id
             $set = int($1);
             push @out, $1, "[msgcat,$1,_1]";
-        } :
+          }
+          :
 
-        /^\$quote (.)/                          ? do {  # quote character
+          /^\$quote (.)/
+          ? do {              # quote character
             $qc = $1;
             $qq = quotemeta($1);
             $qr = qr/$qq?/;
-        } :
+          }
+          :
 
-        /^(\d+) ($qr)(.*?)\2(\\?)$/                     ? do {  # msg_id and msg_str
+          /^(\d+) ($qr)(.*?)\2(\\?)$/
+          ? do {              # msg_id and msg_str
             local $^W;
-            push @out, "$set,".int($1);
+            push @out, "$set," . int($1);
             if ($4) {
                 $msg = $3;
             }
@@ -70,9 +77,11 @@ sub parse {
                 push @out, unescape($qq, $qc, $3);
                 undef $msg;
             }
-        } : 
+          }
+          :
 
-        (defined $msg and /^($qr)(.*?)\1(\\?)$/)        ? do {  # continued string
+          (defined $msg and /^($qr)(.*?)\1(\\?)$/)
+          ? do {    # continued string
             local $^W;
             if ($3) {
                 $msg .= $2;
@@ -81,17 +90,18 @@ sub parse {
                 push @out, unescape($qq, $qc, $msg . $2);
                 undef $msg;
             }
-        } : ();
+          }
+          : ();
     }
 
     push @out, '' if defined $msg;
 
-    return { @out };
+    return {@out};
 }
 
 sub _msgcat {
     my ($self, $set_id, $msg_id, @args) = @_;
-    return $self->maketext(int($set_id).','.int($msg_id), @args)
+    return $self->maketext(int($set_id) . ',' . int($msg_id), @args);
 }
 
 sub unescape {
@@ -111,25 +121,30 @@ L<Locale::Maketext>, L<Locale::Maketext::Lexicon>
 
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>
 
-=head1 COPYRIGHT (The "MIT" License)
+=head1 COPYRIGHT
 
-Copyright 2002, 2003, 2004 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+Copyright 2002, 2003, 2004, 2007 by Audrey Tang E<lt>cpan@audreyt.orgE<gt>.
+
+This software is released under the MIT license cited below.
+
+=head2 The "MIT" License
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-copies of the Software, and to permit persons to whom the Software is fur-
-nished to do so, subject to the following conditions:
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
 
 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.
 
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FIT-
-NESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE X
-CONSORTIUM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
-ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
-WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
+OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
 
 =cut
